@@ -1,10 +1,12 @@
-package Pod::Wordlist::hanekomu;
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
+
+package Pod::Wordlist::hanekomu;
+our $VERSION = '1.100860';
+# ABSTRACT: Add words for spell checking POD
 use Test::Spelling;
 use utf8;
-our $VERSION      = '0.02';
 our @person_names = qw(
   Achim
   Adam
@@ -13,7 +15,7 @@ our @person_names = qw(
   Eilam
   Ekker
   Florian
-  Grünauer
+  Gruenauer
   Heinz
   Helmberger
   Hofstetter
@@ -21,10 +23,13 @@ our @person_names = qw(
   Mark
   Miyagawa
   Ran
+  Ricardo
+  Signes
   Takesako
   Tatsuhiko
 );
 our @tech_names = qw(
+  AnyEvent
   AOP
   API
   AspectJ
@@ -32,11 +37,20 @@ our @tech_names = qw(
   CPAN
   Coro
   DateTime
+  Django
   DBI
+  DSL
   EPP
   FirePHP
   Firefox
+  FIXME
+  GraphViz
+  HTTP
+  IP
+  IPv4
+  IPv6
   MVC
+  MakeMaker
   Markdown
   mkdn
   Middleware
@@ -44,60 +58,111 @@ our @tech_names = qw(
   OOP
   PARC
   PHP
+  Plack
+  PSGI
+  README
   ShipIt
   Spiffy
+  STDIN
+  STDOUT
+  STDERR
+  svk
+  TIMTOWTDI
+  Unicode
+  URI
+  URIs
   W3CDTF
+  XS
   YAML
+  YAML's
 );
 our @stopwords = qw(
+  adaptee
+  adaptees
   administrativa
+  array's
   backend
   behaviour
   blog
   blogs
   bugtracker
+  bundle's
   callback
   callbacks
+  callee
   chomp
   chomps
   configurator
   configurators
   crosscutting
+  denormalized
   distname
+  dotfile
+  dotfiles
   filename
+  formatter
   github
+  hash's
   homepage
   hostname
+  indices
   init
+  japanese
+  Joseki
+  kwalitee
+  marshalling
+  metadata
+  middleware
   mixin
   monkeypatch
   monkeypatches
   monkeypatching
+  munge
   namespace
+  namespaces
   ok
   op
   pipe's
   placeholders
+  pluggable
+  plugin's
   plugins
   pointcut
   pointcuts
   prepends
-  README
+  preprocessed
   redispatch
+  reusability
   ref
   san
   segment's
   shipit
+  startup
+  storable
   stopword
   stopwords
+  stringification
+  stringifications
   stringifies
+  stringify
+  subdirectory
+  subdirectories
+  subobjects
+  terminal's
   tokenizes
+  toolchain
+  unblessed
   unshifts
   username
   uuid
+  value's
+  wellformedness
   whitelist
   whitelists
+  workflow
+  workflows
   wormhole
+  vim
   yml
 );
 
@@ -106,12 +171,19 @@ my %words = map { $_ => 1 } @person_names, @tech_names, @stopwords;
 add_stopwords(sort keys %words);
 $ENV{LANG} = 'C';
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 Pod::Wordlist::hanekomu - Add words for spell checking POD
 
+=head1 VERSION
+
+version 1.100860
+
 =head1 SYNOPSIS
 
     use Test::Spelling;
@@ -123,36 +195,39 @@ Pod::Wordlist::hanekomu - Add words for spell checking POD
 This module, when loaded, adds stopwords for POD spell checking, that is,
 words that should be ignored by the spell check.
 
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Wordlist-hanekomu>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Pod-Wordlist-hanekomu/>.
+site near you, or see
+L<http://search.cpan.org/dist/Pod-Wordlist-hanekomu/>.
 
-The development version lives at L<http://github.com/hanekomu/pod-wordlist-hanekomu/>.
+The development version lives at
+L<http://github.com/hanekomu/Pod-Wordlist-hanekomu/>.
 Instead of sending patches, please fork this project using the standard git
 and github infrastructure.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Marcel GrE<uuml>nauer
+This software is copyright (c) 2009 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
